@@ -119,13 +119,10 @@ def post_live_metrics(
             ```
         params (Optional[Dict[str, Any]]): Updates to DVC param files.
             Defaults to `None`.
-            Only used when `event_type="start"`.
             ```
             params={
                 "dvclive/params.yaml": {
-                    "data": {
-                        "foo": "bar"
-                    }
+                    "foo": "bar"
                 }
             }
             ```
@@ -163,11 +160,10 @@ def post_live_metrics(
         "client": client,
     }
 
-    if event_type == "start":
-        if params:
-            body["params"] = params
+    if params:
+        body["params"] = params
 
-    elif event_type == "data":
+    if event_type == "data":
         if step is None:
             logger.warning("Missing `step` in `data` event.")
             return None
@@ -181,7 +177,7 @@ def post_live_metrics(
         if experiment_rev:
             body["experiment_rev"] = experiment_rev
 
-    else:
+    elif event_type != "start":
         logger.warning(f"Invalid `event_type`: {event_type}")
         return None
 
